;; Generated package description from tramp.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "tramp" "2.8.2" "Transparent Remote Access, Multiple Protocol" '((emacs "28.1")) :commit "31866a54c93ae27f2af72e3fe9b6e180a40c3579" :authors '(("Kai Großjohann" . "kai.grossjohann@gmx.net") ("Michael Albinus" . "michael.albinus@gmx.de")) :maintainer '("Michael Albinus" . "michael.albinus@gmx.de") :keywords '("comm" "processes") :url "https://www.gnu.org/software/tramp/")
